json5: Python implementation of the JSON5 data format
=====================================================

Description
-----------

Python implementation of the JSON5 data format

License
-------

Apache

Upstream Contact
----------------

https://pypi.org/project/json5/

